@@ -1,3 +1,3 @@
-from speedtab.client import Client
+from speedtab.client import Client, create_token
 from speedtab.enums import MergeType, BorderStyle, HorizontalAlignment, VerticalAlignment, WrapStrategy, ShareRole, ChartType, StackedType, LegendPosition, AxisPosition, DefaultColors
-from speedtab.formats import Color, Number, Dollar, Percent, Date, Time, DateTime, Scientific, Border
\ No newline at end of file
+from speedtab.formats import Color, Number, Dollar, Percent, Date, Time, DateTime, Scientific, Border
